package com.usky.system.controller.web;



import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.exception.BusinessErrorCode;
import com.usky.system.controller.web.page.TableDataInfo;
import com.usky.system.domain.SysDictTypeVO;
import com.usky.system.domain.constants.UserConstants;
import com.usky.system.service.ISysDictTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 数据字典信息
 * 
 * @author yq
 */
@RestController
@RequestMapping("/system/dict/type")
public class SysDictTypeController extends BaseController
{
    @Autowired
    private ISysDictTypeService dictTypeService;


    @GetMapping("/list")
    public ApiResult<TableDataInfo> list(SysDictTypeVO dictType)
    {
        startPage();
        List<SysDictTypeVO> list = dictTypeService.selectDictTypeList(dictType);
        return ApiResult.success(getDataTable(list));
    }

    /**
     * 查询字典类型详细
     */
    @GetMapping(value = "/{dictId}")
    public ApiResult getInfo(@PathVariable Long dictId)
    {
        return ApiResult.success(dictTypeService.selectDictTypeById(dictId));
    }

    /**
     * 新增字典类型
     */
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysDictTypeVO dict)
    {
        if (UserConstants.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict)))
        {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "新增字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
//        dict.setCreateBy(SecurityUtils.getUsername());
        return toAjax(dictTypeService.insertDictType(dict));
    }

    /**
     * 修改字典类型
     */
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysDictTypeVO dict)
    {
        if (UserConstants.NOT_UNIQUE.equals(dictTypeService.checkDictTypeUnique(dict)))
        {
            return ApiResult.error(BusinessErrorCode.BIZ_BUSINESS_ERROR.getCode(), "修改字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
//        dict.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(dictTypeService.updateDictType(dict));
    }

    /**
     * 删除字典类型
     */
    @DeleteMapping("/{dictIds}")
    public ApiResult remove(@PathVariable Long[] dictIds)
    {
        dictTypeService.deleteDictTypeByIds(dictIds);
        return ApiResult.success();
    }

    /**
     * 刷新字典缓存
     */
    @DeleteMapping("/refreshCache")
    public ApiResult refreshCache()
    {
        dictTypeService.resetDictCache();
        return ApiResult.success();
    }

    /**
     * 获取字典选择框列表
     */
    @GetMapping("/optionselect")
    public ApiResult optionselect()
    {
        List<SysDictTypeVO> dictTypes = dictTypeService.selectDictTypeAll();
        return ApiResult.success(dictTypes);
    }
}
